@@ -939,8 +939,13 @@ nm_update_state(NMState state)
 #if NM_CHECK_VERSION(0,8,992)
 		case NM_STATE_DISCONNECTING:
 #endif
+#if NM_CHECK_VERSION(1,0,0)
+			if (prev != NM_STATE_CONNECTED_GLOBAL && prev != NM_STATE_UNKNOWN)
+				break;
+#else
 			if (prev != NM_STATE_CONNECTED && prev != NM_STATE_UNKNOWN)
 				break;
+#endif
 			if (ui_ops != NULL && ui_ops->network_disconnected != NULL)
 				ui_ops->network_disconnected();
 			break;
@@ -1225,9 +1230,9 @@ purple_network_init(void)
 	purple_prefs_add_int	 ("/purple/network/turn_port_tcp", 3478);
 	purple_prefs_add_string("/purple/network/turn_username", "");
 	purple_prefs_add_string("/purple/network/turn_password", "");
-	purple_prefs_add_bool  ("/purple/network/auto_ip", TRUE);
+	purple_prefs_add_bool  ("/purple/network/auto_ip", FALSE);
 	purple_prefs_add_string("/purple/network/public_ip", "");
-	purple_prefs_add_bool  ("/purple/network/map_ports", TRUE);
+	purple_prefs_add_bool  ("/purple/network/map_ports", FALSE);
 	purple_prefs_add_bool  ("/purple/network/ports_range_use", FALSE);
 	purple_prefs_add_int   ("/purple/network/ports_range_start", 1024);
 	purple_prefs_add_int   ("/purple/network/ports_range_end", 2048);
