@@ -31,6 +31,7 @@
 #include "core.h"
 #include "dbus-maybe.h"
 #include "debug.h"
+#include "glibcompat.h"
 #include "notify.h"
 #include "prefs.h"
 #include "status.h"
@@ -296,8 +297,8 @@ purple_status_type_destroy(PurpleStatusType *status_type)
 	g_free(status_type->name);
 	g_free(status_type->primary_attr_id);
 
-	g_list_foreach(status_type->attrs, (GFunc)purple_status_attr_destroy, NULL);
-	g_list_free(status_type->attrs);
+	g_list_free_full(status_type->attrs,
+	                 (GDestroyNotify)purple_status_attr_destroy);
 
 	PURPLE_DBUS_UNREGISTER_POINTER(status_type);
 	g_free(status_type);
@@ -831,9 +832,7 @@ purple_status_set_active_with_attrs_list(PurpleStatus *status, gboolean active,
 			if (default_value->type == PURPLE_TYPE_STRING) {
 				const char *cur = purple_status_get_attr_string(status, attr->id);
 				const char *def = purple_value_get_string(default_value);
-				if ((cur == NULL && def == NULL)
-				    || (cur != NULL && def != NULL
-					&& !strcmp(cur, def))) {
+				if (purple_strequal(cur, def)) {
 					continue;
 				}
 
@@ -1176,8 +1175,7 @@ purple_presence_destroy(PurplePresence *presence)
 		g_free(presence->u.chat.user);
 	}
 
-	g_list_foreach(presence->statuses, (GFunc)purple_status_destroy, NULL);
-	g_list_free(presence->statuses);
+	g_list_free_full(presence->statuses, (GDestroyNotify)purple_status_destroy);
 
 	g_hash_table_destroy(presence->status_table);
 
